@@ -5,7 +5,7 @@ module ActiveRecord::Import::MysqlAdapter
   NO_MAX_PACKET = 0
   QUERY_OVERHEAD = 8 #This was shown to be true for MySQL, but it's not clear where the overhead is from.
 
-  # +sql+ can be a single string or an array. If it is an array all 
+  # +sql+ can be a single string or an array. If it is an array all
   # elements that are in position >= 1 will be appended to the final SQL.
   def insert_many( sql, values, *args ) # :nodoc:
     # the number of inserts default
@@ -46,7 +46,7 @@ module ActiveRecord::Import::MysqlAdapter
       end
     end
 
-    number_of_inserts
+    [number_of_inserts,[]]
   end
 
   # Returns the maximum number of bytes that the server will allow
