@@ -10,13 +10,19 @@ ENV["RAILS_ENV"] = "test"
 require "bundler"
 Bundler.setup
 
-require "logger"
-require 'test/unit'
 require "active_record"
 require "active_record/fixtures"
 require "active_support/test_case"
 
-require "delorean"
+if ActiveSupport::VERSION::STRING < "4.1"
+  require 'test/unit'
+else
+  require 'active_support/testing/autorun'
+end
+
+require 'timecop'
+require 'chronic'
+
 require "ruby-debug" if RUBY_VERSION.to_f < 1.9
 
 adapter = ENV["ARE_DB"] || "sqlite3"
@@ -25,6 +31,7 @@ FileUtils.mkdir_p 'log'
 ActiveRecord::Base.logger = Logger.new("log/test.log")
 ActiveRecord::Base.logger.level = Logger::DEBUG
 ActiveRecord::Base.configurations["test"] = YAML.load_file(test_dir.join("database.yml"))[adapter]
+ActiveRecord::Base.default_timezone = :utc
 
 require "activerecord-import"
 ActiveRecord::Base.establish_connection "test"
